@@ -35,4 +35,6 @@ char *ugetKey();
 char *ugetKeyUnderConsole();
 char *ugetKeyUnderX();
 
+//the Unicode character returned by ugetKey()
+char uc[5];
 #endif
