@@ -23,31 +23,97 @@
 
 void drawForm() 
 {
-  int designW = SCREEN_W-18;
-  int designH = SCREEN_H-4;
+  int designW = SCREEN_W-16;
+  int designH = SCREEN_H-3;
+  static int startX = 0;
+  static int startY = 0;
   int i;
   char *tmp = (char *) malloc(MAX_FORM_TITLE_LEN);
   strcpy(tmp, "(");
   strcat(tmp, FORM_TITLE);
   strcat(tmp, "): Design\0");
-  drawBox(3, 1, SCREEN_H-1, SCREEN_W-16, tmp, YES);
-  free(tmp);
-  //if(FORM_HEIGHT <= designH && FORM_WIDTH <= designW) {
-    //drawBox(4, 2, FORM_HEIGHT+4, FORM_WIDTH+2, FORM_TITLE, YES);
-  for(i = 0; i < total_form_tools; i++) 
+  if(FORM_HEIGHT <= designH && FORM_WIDTH <= designW) 
   {
-    if(i == selected_form_tool)
-      setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
-    else 
-      setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
-    printf("\e[%d;%dH", tool_pos[i].x+3, tool_pos[i].y+1);
-    printf("%s", form_tool_text[i]);
+    //drawBox(3, 1, SCREEN_H-1, SCREEN_W-16, "", YES);
+    //drawBox(3, 1, FORM_HEIGHT+4, FORM_WIDTH+2, FORM_TITLE, YES);
+    drawBox(3, 1, FORM_HEIGHT+4, FORM_WIDTH+2, tmp, YES);
   }
-  printf("\e[%d;%dH", tool_pos[selected_form_tool].x+3, 
+  else
+  {
+    drawBox(3, 1, SCREEN_H-1, SCREEN_W-16, tmp, YES);
+    if(startY == 0)
+    {
+      if(//adding_tool &&
+	 (tool_pos[selected_form_tool].y+
+			 strlen(form_tool_text[selected_form_tool]))
+					> designW-2)
+	startY++;
+    }
+    else
+    {
+      if(tool_pos[selected_form_tool].y < startY)
+	startY--;
+      else if(//adding_tool &&
+	      (tool_pos[selected_form_tool].y+
+	      strlen(form_tool_text[selected_form_tool]))
+					> designW-2)
+	startY++;
+    }//end inner if
+    if(startX == 0)
+    {
+      if(//adding_tool && 
+	tool_pos[selected_form_tool].x >= designH-2)
+	startX++;
+    }
+    else
+    {
+      if(tool_pos[selected_form_tool].x < startX)
+	startX--;
+      else if(//adding_tool &&
+	      startX+tool_pos[selected_form_tool].x >= designH-2)
+	startX++;
+    }//end inner if
+  }
+  free(tmp);
+  /////////////////////////////////////////////
+  //draw the tools
+  /////////////////////////////////////////////
+  if(FORM_HEIGHT <= designH && FORM_WIDTH <= designW)
+  {
+    for(i = 0; i < total_form_tools; i++) 
+    {
+      if(i == selected_form_tool)
+        setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
+      else 
+        setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+      printf("\e[%d;%dH", tool_pos[i].x+3, tool_pos[i].y+1);
+      printf("%s", form_tool_text[i]);
+    }
+    printf("\e[%d;%dH", tool_pos[selected_form_tool].x+3, 
 		      tool_pos[selected_form_tool].y+1
 		      +strlen(form_tool_text[selected_form_tool]));
-  //}
-
+  }
+  else
+  {
+    for(i = 0; i < total_form_tools; i++) 
+    {
+      if(tool_pos[i].x < startX || tool_pos[i].x > startX+designH)
+	continue;
+      if(tool_pos[i].y+strlen(form_tool_text[selected_form_tool]) <
+	  startY || tool_pos[i].y > startY+designW)
+	continue;
+      if(i == selected_form_tool)
+        setScreenColors(FG_COLOR[COLOR_HIGHLIGHT_TEXT], BG_COLOR[COLOR_HIGHLIGHT_TEXT]);
+      else 
+        setScreenColors(FG_COLOR[COLOR_WINDOW], BG_COLOR[COLOR_WINDOW]);
+      printf("\e[%d;%dH", tool_pos[i].x+3-startX, tool_pos[i].y+1);
+      printf("%s", form_tool_text[i]+((startY+1>tool_pos[i].y) ?
+				      (startY+1-tool_pos[i].y):0));
+    }
+    printf("\e[%d;%dH", tool_pos[selected_form_tool].x+3-startX, 
+		      tool_pos[selected_form_tool].y+1-startY
+		      +strlen(form_tool_text[selected_form_tool]));
+  }
   fflush(stdout);
 }
 
