@@ -1049,6 +1049,34 @@ void checkFileExtension()
   {
     AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
     HIGHLIGHT_MODE = PERL_MODE;
+  //is it a texi file?
+  } 
+  else if((open_file_name[i-1] == 'i' && open_file_name[i-2] == 'x' 
+	  && open_file_name[i-3] == 'e' && open_file_name[i-5] == 't'
+	  && open_file_name[i-5] == '.') ||
+	  (open_file_name[i-1] == 'i' && open_file_name[i-2] == 'x' 
+	  && open_file_name[i-3] == 't' && open_file_name[i-4] == '.') ||
+	  (open_file_name[i-8] == 'o' && open_file_name[i-7] == 'f' 
+	  && open_file_name[i-6] == 'n' && open_file_name[i-5] == 'i' 
+	  && open_file_name[i-4] == 'x' && open_file_name[i-3] == 'e' 
+	  && open_file_name[i-2] == 't' && open_file_name[i-1] == '.')) 
+  {
+    AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
+    HIGHLIGHT_MODE = TEXI_MODE;
+  //is it an assembly file?
+  } 
+  else if((open_file_name[i-1] == 'm' && open_file_name[i-2] == 's' 
+	   && open_file_name[i-3] == 'a' && open_file_name[i-4] == '.'))
+  {
+    AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
+    HIGHLIGHT_MODE = ASM_MODE;
+  //is it python source file?
+  } 
+  else if((open_file_name[i-1] == 'y' && open_file_name[i-2] == 'p' 
+	   && open_file_name[i-3] == '.'))
+  {
+    AUTO_HIGHLIGHTING = 1; BG_COLOR[COLOR_WINDOW] = COLOR_HWINDOW;
+    HIGHLIGHT_MODE = PYTHON_MODE;
   //NONE of the above...
   } 
   else 
