@@ -1420,6 +1420,912 @@ void loadKeywords(hmode mode)
       keyword[408] = "STDOUT";
       total_keywords = 409;
       break;
+      /////////////////////////////////////////////////
+      /////////////////////////////////////////////////
+      /////////////////////////////////////////////////
+    case(TEXI_MODE):
+      //TEXI keywords
+      keyword[0] = "@!";
+      keyword[1] = "@\"";
+      keyword[2] = "@'";
+      keyword[3] = "@*";
+      keyword[4] = "@,";
+      keyword[5] = "@-";
+      keyword[6] = "@.";
+      keyword[7] = "@/";
+      keyword[8] = "@:";
+      keyword[9] = "@=";
+      keyword[10] = "@?";
+      keyword[11] = "@@";
+      keyword[12] = "@atchar";
+      keyword[13] = "@\\";
+      keyword[14] = "@^";
+      keyword[15] = "@`";
+      keyword[16] = "@{";
+      keyword[17] = "@lbracechar";
+      keyword[18] = "@}";
+      keyword[19] = "@rbracechar";
+      keyword[20] = "@~";
+      keyword[21] = "@AA";
+      keyword[22] = "@aa";
+      keyword[23] = "@abbr";
+      keyword[24] = "@acronym";
+      keyword[25] = "@AE";
+      keyword[26] = "@ae";
+      keyword[27] = "@afivepaper";
+      keyword[28] = "@afourlatex";
+      keyword[29] = "@afourpaper";
+      keyword[30] = "@afourwide";
+      keyword[31] = "@alias";
+      keyword[32] = "@allowcodebreaks";
+      keyword[33] = "@anchor";
+      keyword[34] = "@appendixsection";
+      keyword[35] = "@appendixsec";
+      keyword[36] = "@appendixsubsec";
+      keyword[37] = "@appendixsubsubsec";
+      keyword[38] = "@appendix";
+      keyword[39] = "@arrow";
+      keyword[40] = "@asis";
+      keyword[41] = "@author";
+      keyword[42] = "@bullet";
+      keyword[43] = "@bye";
+      keyword[44] = "@b";
+      keyword[45] = "@caption";
+      keyword[46] = "@cartouche";
+      keyword[47] = "@centerchap";
+      keyword[48] = "@center";
+      keyword[49] = "@chapheading";
+      keyword[50] = "@chapter";
+      keyword[51] = "@cindex";
+      keyword[52] = "@cite";
+      keyword[53] = "@clear";
+      keyword[54] = "@clicksequence";
+      keyword[55] = "@clickstyle";
+      keyword[56] = "@click";
+      keyword[57] = "@codequotebacktick";
+      keyword[58] = "@codequoteundirected";
+      keyword[59] = "@code";
+      keyword[60] = "@command";
+      keyword[61] = "@comma";
+      keyword[62] = "@comment";
+      keyword[63] = "@contents";
+      keyword[64] = "@copying";
+      keyword[65] = "@copyright";
+      keyword[66] = "@c";
+      keyword[67] = "@defcodeindex";
+      keyword[68] = "@defcvx";
+      keyword[69] = "@defcv";
+      keyword[70] = "@deffnx";
+      keyword[71] = "@deffn";
+      keyword[72] = "@defindex";
+      keyword[73] = "@definfoenclose";
+      keyword[74] = "@defivarx";
+      keyword[75] = "@defivar";
+      keyword[76] = "@defmacx";
+      keyword[77] = "@defmac";
+      keyword[78] = "@defmethodx";
+      keyword[79] = "@defmethod";
+      keyword[80] = "@defoptx";
+      keyword[81] = "@defopt";
+      keyword[82] = "@defopx";
+      keyword[83] = "@defop";
+      keyword[84] = "@defspecx";
+      keyword[85] = "@defspec";
+      keyword[86] = "@deftpx";
+      keyword[87] = "@deftp";
+      keyword[88] = "@deftypecvx";
+      keyword[89] = "@deftypecv";
+      keyword[90] = "@deftypefnnewline";
+      keyword[91] = "@deftypefnx";
+      keyword[92] = "@deftypefn";
+      keyword[93] = "@deftypefunx";
+      keyword[94] = "@deftypefun";
+      keyword[95] = "@deftypeivarx";
+      keyword[96] = "@deftypeivar";
+      keyword[97] = "@deftypemethodx";
+      keyword[98] = "@deftypemethod";
+      keyword[99] = "@deftypeopx";
+      keyword[100] = "@deftypeop";
+      keyword[101] = "@deftypevarx";
+      keyword[102] = "@deftypevar";
+      keyword[103] = "@deftypevrx";
+      keyword[104] = "@deftypevr";
+      keyword[105] = "@defunx";
+      keyword[106] = "@defun";
+      keyword[107] = "@defvarx";
+      keyword[108] = "@defvar";
+      keyword[109] = "@defvrx";
+      keyword[110] = "@defvr";
+      keyword[111] = "@detailmenu";
+      keyword[112] = "@dfn";
+      keyword[113] = "@DH";
+      keyword[114] = "@dh";
+      keyword[115] = "@dircategory";
+      keyword[116] = "@direntry";
+      keyword[117] = "@display";
+      keyword[118] = "@dmn";
+      keyword[119] = "@docbook";
+      keyword[120] = "@documentdescription";
+      keyword[121] = "@documentlanguage";
+      keyword[122] = "@dotaccent";
+      keyword[123] = "@dotless";
+      keyword[124] = "@dots";
+      keyword[125] = "@email";
+      keyword[126] = "@emph";
+      keyword[127] = "@enddots";
+      keyword[128] = "@end";
+      keyword[129] = "@enumerate";
+      keyword[130] = "@env";
+      keyword[131] = "@equiv";
+      keyword[132] = "@errormsg";
+      keyword[133] = "@error";
+      keyword[134] = "@euro";
+      keyword[135] = "@evenfooting";
+      keyword[136] = "@evenheading";
+      keyword[137] = "@exampleindent";
+      keyword[138] = "@example";
+      keyword[139] = "@exclamdown";
+      keyword[140] = "@exdent";
+      keyword[141] = "@expansion";
+      keyword[142] = "@file";
+      keyword[143] = "@finalout";
+      keyword[144] = "@findex";
+      keyword[145] = "@firstparagraphindent";
+      keyword[146] = "@float";
+      keyword[147] = "@flushleft";
+      keyword[148] = "@flushright";
+      keyword[149] = "@fonttextsize";
+      keyword[150] = "@footnotestyle";
+      keyword[151] = "@footnote";
+      keyword[152] = "@format";
+      keyword[153] = "@frenchspacing";
+      keyword[154] = "@ftable";
+      keyword[155] = "@geq";
+      keyword[156] = "@group";
+      keyword[157] = "@guillemetleft";
+      keyword[158] = "@guillemetright";
+      keyword[159] = "@guillemotleft";
+      keyword[160] = "@guillemotright";
+      keyword[161] = "@guilsinglleft";
+      keyword[162] = "@guilsinglright";
+      keyword[163] = "@H";
+      keyword[164] = "@hashchar";
+      keyword[165] = "@headings";
+      keyword[166] = "@heading";
+      keyword[167] = "@headitemfont";
+      keyword[168] = "@headitem";
+      keyword[169] = "@html";
+      keyword[170] = "@hyphenation";
+      keyword[171] = "@ifcommanddefined";
+      keyword[172] = "@ifcommandnotdefined";
+      keyword[173] = "@ifdocbook";
+      keyword[174] = "@ifhtml";
+      keyword[175] = "@ifinfo";
+      keyword[176] = "@ifnotdocbook";
+      keyword[177] = "@ifnothtml";
+      keyword[178] = "@ifnotplaintext";
+      keyword[179] = "@ifnottex";
+      keyword[180] = "@ifnotxml";
+      keyword[181] = "@ifnotinfo";
+      keyword[182] = "@ifplaintext";
+      keyword[183] = "@ifset";
+      keyword[184] = "@iftex";
+      keyword[185] = "@ifxml";
+      keyword[186] = "@ignore";
+      keyword[187] = "@image";
+      keyword[188] = "@include";
+      keyword[189] = "@indentedblock";
+      keyword[190] = "@indent";
+      keyword[191] = "@indicateurl";
+      keyword[192] = "@inforef";
+      keyword[193] = "@inlinefmtifelse";
+      keyword[194] = "@inlinefmt";
+      keyword[195] = "@inlineifclear";
+      keyword[196] = "@inlineifset";
+      keyword[197] = "@inlineraw";
+      keyword[198] = "\\input";
+      keyword[199] = "@insertcopying";
+      keyword[200] = "@itemize";
+      keyword[201] = "@itemx";
+      keyword[202] = "@item";
+      keyword[203] = "@i";
+      keyword[204] = "@kbdinputstyle";
+      keyword[205] = "@kbd";
+      keyword[206] = "@key";
+      keyword[207] = "@kindex";
+      keyword[208] = "@LaTeX";
+      keyword[209] = "@leq";
+      keyword[210] = "@lisp";
+      keyword[211] = "@listoffloats";
+      keyword[212] = "@lowersections";
+      keyword[213] = "@L";
+      keyword[214] = "@l";
+      keyword[215] = "@macro";
+      keyword[216] = "@majorheading";
+      keyword[217] = "@math";
+      keyword[218] = "@menu";
+      keyword[219] = "@minus";
+      keyword[220] = "@multitable";
+      keyword[221] = "@need";
+      keyword[222] = "@node";
+      keyword[223] = "@noindent";
+      keyword[224] = "@novalidate";
+      keyword[225] = "@oddfooting";
+      keyword[226] = "@oddheading";
+      keyword[227] = "@OE";
+      keyword[228] = "@oe";
+      keyword[229] = "@ogonek";
+      keyword[230] = "@option";
+      keyword[231] = "@ordf";
+      keyword[232] = "@ordm";
+      keyword[233] = "@O";
+      keyword[234] = "@o";
+      keyword[235] = "@pagesizes";
+      keyword[236] = "@page";
+      keyword[237] = "@paragraphindent";
+      keyword[238] = "@part";
+      keyword[239] = "@pindex";
+      keyword[240] = "@point";
+      keyword[241] = "@pounds";
+      keyword[242] = "@printindex";
+      keyword[243] = "@print";
+      keyword[244] = "@pxref";
+      keyword[245] = "@questiondown";
+      keyword[246] = "@quotation";
+      keyword[247] = "@quotedblleft";
+      keyword[248] = "@quotedblright";
+      keyword[249] = "@quoteleft";
+      keyword[250] = "@quoteright";
+      keyword[251] = "@quotedblbase";
+      keyword[252] = "@quotesinglbase";
+      keyword[253] = "@raggedright";
+      keyword[254] = "@raisesections";
+      keyword[255] = "@refill";
+      keyword[256] = "@ref";
+      keyword[257] = "@registeredsymbol";
+      keyword[258] = "@result";
+      keyword[259] = "@ringaccent";
+      keyword[260] = "@r";
+      keyword[261] = "@samp";
+      keyword[262] = "@sansserif";
+      keyword[263] = "@sc";
+      keyword[264] = "@section";
+      keyword[265] = "@setchapternewpage";
+      keyword[266] = "@setcontentsaftertitlepage";
+      keyword[267] = "@setfilename";
+      keyword[268] = "@setshortcontentsaftertitlepage";
+      keyword[269] = "@settitle";
+      keyword[270] = "@set";
+      keyword[271] = "@shortcaption";
+      keyword[272] = "@shortcontents";
+      keyword[273] = "@shorttitlepage";
+      keyword[274] = "@slanted";
+      keyword[275] = "@smallbook";
+      keyword[276] = "@smalldisplay";
+      keyword[277] = "@smallexample";
+      keyword[278] = "@smallformat";
+      keyword[279] = "@smallindentedblock";
+      keyword[280] = "@smalllisp";
+      keyword[281] = "@smallquotation";
+      keyword[282] = "@sp";
+      keyword[283] = "@ss";
+      keyword[284] = "@strong";
+      keyword[285] = "@subheading";
+      keyword[286] = "@subsection";
+      keyword[287] = "@subsubheading";
+      keyword[288] = "@subsubsection";
+      keyword[289] = "@subtitle";
+      keyword[290] = "@summarycontents";
+      keyword[291] = "@syncodeindex";
+      keyword[292] = "@synindex";
+      keyword[293] = "@table";
+      keyword[294] = "@tab";
+      keyword[295] = "@textdegree";
+      keyword[296] = "@TeX";
+      keyword[297] = "@tex";
+      keyword[298] = "@thischapter";
+      keyword[299] = "@thischaptername";
+      keyword[300] = "@thischapternum";
+      keyword[301] = "@thisfile";
+      keyword[302] = "@thispage";
+      keyword[303] = "@thistitle";
+      keyword[304] = "@TH";
+      keyword[305] = "@th";
+      keyword[306] = "@tieaccent";
+      keyword[307] = "@tie";
+      keyword[308] = "@tindex";
+      keyword[309] = "@titlefont";
+      keyword[310] = "@titlepage";
+      keyword[311] = "@title";
+      keyword[312] = "@today";
+      keyword[313] = "@top";
+      keyword[314] = "@t";
+      keyword[315] = "@ubaraccent";
+      keyword[316] = "@udotaccent";
+      keyword[317] = "@unmacro";
+      keyword[318] = "@unnumberedsec";
+      keyword[319] = "@unnumberedsubsec";
+      keyword[320] = "@unnumberedsubsubsec";
+      keyword[321] = "@unnumbered";
+      keyword[322] = "@url";
+      keyword[323] = "@urefbreakstyle";
+      keyword[324] = "@uref";
+      keyword[325] = "@u";
+      keyword[326] = "@value";
+      keyword[327] = "@var";
+      keyword[328] = "@verbatiminclude";
+      keyword[329] = "@verbatim";
+      keyword[330] = "@verb";
+      keyword[331] = "@vindex";
+      keyword[332] = "@vskip";
+      keyword[333] = "@vtable";
+      keyword[334] = "@v";
+      keyword[335] = "@w";
+      keyword[336] = "@xml";
+      keyword[337] = "@xrefautomaticsectiontitle";
+      keyword[338] = "@xref";
+      keyword[339] = "@";
+      total_keywords = 340;
+      break;
+      /////////////////////////////////////////////////
+      /////////////////////////////////////////////////
+      /////////////////////////////////////////////////
+    case(ASM_MODE):
+      //x86 assembly instructions
+      keyword[0] = "AAA";
+      keyword[1] = "aaa";
+      keyword[2] = "AAD";
+      keyword[3] = "aad";
+      keyword[4] = "AAM";
+      keyword[5] = "aam";
+      keyword[6] = "AAS";
+      keyword[7] = "aas";
+      keyword[8] = "AAC";
+      keyword[9] = "aac";
+      keyword[10] = "ADD";
+      keyword[11] = "add";
+      keyword[12] = "AND";
+      keyword[13] = "and";
+      keyword[14] = "CALL";
+      keyword[15] = "call";
+      keyword[16] = "CBW";
+      keyword[17] = "cbw";
+      keyword[18] = "CLC";
+      keyword[19] = "clc";
+      keyword[20] = "CLD";
+      keyword[21] = "cld";
+      keyword[22] = "CLI";
+      keyword[23] = "cli";
+      keyword[24] = "CMC";
+      keyword[25] = "cmc";
+      keyword[26] = "CMPSB";
+      keyword[27] = "cmpsb";
+      keyword[28] = "CMPSW";
+      keyword[29] = "cmpsw";
+      keyword[30] = "CWD";
+      keyword[31] = "cwd";
+      keyword[32] = "DAA";
+      keyword[33] = "daa";
+      keyword[34] = "DAS";
+      keyword[35] = "das";
+      keyword[36] = "DEC";
+      keyword[37] = "dec";
+      keyword[38] = "DIV";
+      keyword[39] = "div";
+      keyword[40] = "ESC";
+      keyword[41] = "esc";
+      keyword[42] = "HLT";
+      keyword[43] = "hlt";
+      keyword[44] = "IDIV";
+      keyword[45] = "idiv";
+      keyword[46] = "IMUL";
+      keyword[47] = "imul";
+      keyword[48] = "INC";
+      keyword[49] = "inc";
+      keyword[50] = "INTO";
+      keyword[51] = "into";
+      keyword[52] = "INT";
+      keyword[53] = "int";
+      keyword[54] = "INS";
+      keyword[55] = "ins";
+      keyword[56] = "IN";
+      keyword[57] = "in";
+      keyword[58] = "IRET";
+      keyword[59] = "iret";
+      keyword[60] = "JCC";
+      keyword[61] = "jcc";
+      keyword[62] = "JCXZ";
+      keyword[63] = "jcxz";
+      keyword[64] = "JMP";
+      keyword[65] = "jmp";
+      keyword[66] = "LAHF";
+      keyword[67] = "lahf";
+      keyword[68] = "LDS";
+      keyword[69] = "lds";
+      keyword[70] = "LEA";
+      keyword[71] = "lea";
+      keyword[72] = "LES";
+      keyword[73] = "les";
+      keyword[74] = "LOCK";
+      keyword[75] = "lock";
+      keyword[76] = "LODSB";
+      keyword[77] = "lodsb";
+      keyword[78] = "LODSW";
+      keyword[79] = "lodsw";
+      keyword[80] = "LOOPNE";
+      keyword[81] = "loopne";
+      keyword[82] = "LOOPNZ";
+      keyword[83] = "loopnz";
+      keyword[84] = "LOOPE";
+      keyword[85] = "loope";
+      keyword[86] = "LOOPZ";
+      keyword[87] = "loopz";
+      keyword[88] = "LOOPW";
+      keyword[89] = "loopw";
+      keyword[90] = "LOOPD";
+      keyword[91] = "loopd";
+      keyword[92] = "LOOP";
+      keyword[93] = "loop";
+      keyword[94] = "MOVSB";
+      keyword[95] = "movsb";
+      keyword[96] = "MOVSW";
+      keyword[97] = "movsw";
+      keyword[98] = "MOVSD";
+      keyword[99] = "movsd";
+      keyword[100] = "MOVSX";
+      keyword[101] = "movsx";
+      keyword[102] = "MOVZX";
+      keyword[103] = "movzx";
+      keyword[104] = "MOVNTDQ";
+      keyword[105] = "movntdq";
+      keyword[106] = "MOVNTI";
+      keyword[107] = "movnti";
+      keyword[108] = "MOVNTPD";
+      keyword[109] = "movntpd";
+      keyword[110] = "MOVSXD";
+      keyword[111] = "movsxd";
+      keyword[112] = "MOV";
+      keyword[113] = "mov";
+      keyword[114] = "MUL";
+      keyword[115] = "mul";
+      keyword[116] = "NEG";
+      keyword[117] = "neg";
+      keyword[118] = "NOP";
+      keyword[119] = "nop";
+      keyword[120] = "NOT";
+      keyword[121] = "not";
+      keyword[122] = "OR";
+      keyword[123] = "or";
+      keyword[124] = "OUTSD";
+      keyword[125] = "outsd";
+      keyword[126] = "OUT";
+      keyword[127] = "out";
+      keyword[128] = "POPFQ";
+      keyword[129] = "popfq";
+      keyword[130] = "PUSHFQ";
+      keyword[131] = "pushfq";
+      keyword[132] = "POPAD";
+      keyword[133] = "popad";
+      keyword[134] = "POPA";
+      keyword[135] = "popa";
+      keyword[136] = "PUSHAD";
+      keyword[137] = "pushad";
+      keyword[138] = "PUSHFD";
+      keyword[139] = "pushfd";
+      keyword[140] = "PUSHA";
+      keyword[141] = "pusha";
+      keyword[142] = "POPFD";
+      keyword[143] = "popfd";
+      keyword[144] = "POPF";
+      keyword[145] = "popf";
+      keyword[146] = "POP";
+      keyword[147] = "pop";
+      keyword[148] = "PUSHF";
+      keyword[149] = "pushf";
+      keyword[150] = "PUSH";
+      keyword[151] = "push";
+      keyword[152] = "RCL";
+      keyword[153] = "rcl";
+      keyword[154] = "RCR";
+      keyword[155] = "rcr";
+      keyword[156] = "REPE";
+      keyword[157] = "repe";
+      keyword[158] = "PERNE";
+      keyword[159] = "repne";
+      keyword[160] = "REPNZ";
+      keyword[161] = "repnz";
+      keyword[162] = "REPZ";
+      keyword[163] = "repz";
+      keyword[164] = "REP";
+      keyword[165] = "rep";
+      keyword[166] = "RETN";
+      keyword[167] = "retn";
+      keyword[168] = "RETF";
+      keyword[169] = "retf";
+      keyword[170] = "RET";
+      keyword[171] = "ret";
+      keyword[172] = "ROL";
+      keyword[173] = "rol";
+      keyword[174] = "ROR";
+      keyword[175] = "ror";
+      keyword[176] = "SAHF";
+      keyword[177] = "sahf";
+      keyword[178] = "SAL";
+      keyword[179] = "sal";
+      keyword[180] = "SAR";
+      keyword[181] = "sar";
+      keyword[182] = "SBB";
+      keyword[183] = "sbb";
+      keyword[184] = "SCASD";
+      keyword[185] = "scasd";
+      keyword[186] = "SHLD";
+      keyword[187] = "shld";
+      keyword[188] = "SHRD";
+      keyword[189] = "shrd";
+      keyword[190] = "STOSD";
+      keyword[191] = "stosd";
+      keyword[192] = "SCASB";
+      keyword[193] = "scasb";
+      keyword[194] = "SCASW";
+      keyword[195] = "scasw";
+      keyword[196] = "SHL";
+      keyword[197] = "shl";
+      keyword[198] = "SHR";
+      keyword[199] = "shr";
+      keyword[200] = "STC";
+      keyword[201] = "stc";
+      keyword[202] = "STD";
+      keyword[203] = "std";
+      keyword[204] = "STI";
+      keyword[205] = "sti";
+      keyword[206] = "SCASQ";
+      keyword[207] = "scasq";
+      keyword[208] = "STOSQ";
+      keyword[209] = "stosq";
+      keyword[210] = "STOSB";
+      keyword[211] = "stosb";
+      keyword[212] = "STOSW";
+      keyword[213] = "stosw";
+      keyword[214] = "SUB";
+      keyword[215] = "sub";
+      keyword[216] = "TEST";
+      keyword[217] = "test";
+      keyword[218] = "WAIT";
+      keyword[219] = "wait";
+      keyword[220] = "XCHG";
+      keyword[221] = "xchg";
+      keyword[222] = "XLAT";
+      keyword[223] = "xlat";
+      keyword[224] = "XOR";
+      keyword[225] = "xor";
+      keyword[226] = "BOUND";
+      keyword[227] = "bound";
+      keyword[228] = "ENTER";
+      keyword[229] = "enter";
+      keyword[230] = "LEAVE";
+      keyword[231] = "leave";
+      keyword[232] = "OUTS";
+      keyword[233] = "outs";
+      keyword[234] = "ARPL";
+      keyword[235] = "arpl";
+      keyword[236] = "CLTS";
+      keyword[237] = "clts";
+      keyword[238] = "LAR";
+      keyword[239] = "lar";
+      keyword[240] = "LGDT";
+      keyword[241] = "lgdt";
+      keyword[242] = "LIDT";
+      keyword[243] = "lidt";
+      keyword[244] = "LLDT";
+      keyword[245] = "lldt";
+      keyword[246] = "LMSW";
+      keyword[247] = "lmsw";
+      keyword[248] = "LOADALL";
+      keyword[249] = "loadall";
+      keyword[250] = "LSL";
+      keyword[251] = "lsl";
+      keyword[252] = "LTR";
+      keyword[253] = "ltr";
+      keyword[254] = "SGDT";
+      keyword[255] = "sgdt";
+      keyword[256] = "SIDT";
+      keyword[257] = "sidt";
+      keyword[258] = "SLDT";
+      keyword[259] = "sldt";
+      keyword[260] = "SMSW";
+      keyword[261] = "smsw";
+      keyword[262] = "STR";
+      keyword[263] = "str";
+      keyword[264] = "VERR";
+      keyword[265] = "verr";
+      keyword[266] = "VERW";
+      keyword[267] = "verw";
+      keyword[268] = "BSF";
+      keyword[269] = "bsf";
+      keyword[270] = "BSR";
+      keyword[271] = "bsr";
+      keyword[272] = "BTC";
+      keyword[273] = "btc";
+      keyword[274] = "BTR";
+      keyword[275] = "btr";
+      keyword[276] = "BTS";
+      keyword[277] = "bts";
+      keyword[278] = "BT";
+      keyword[279] = "bt";
+      keyword[280] = "CDQ";
+      keyword[281] = "cdq";
+      keyword[282] = "CMPSD";
+      keyword[283] = "cmpsd";
+      keyword[284] = "CWDE";
+      keyword[285] = "cwde";
+      keyword[286] = "INSD";
+      keyword[287] = "insd";
+      keyword[288] = "JECXZ";
+      keyword[289] = "jecxz";
+      keyword[290] = "LFS";
+      keyword[291] = "lfs";
+      keyword[292] = "LGS";
+      keyword[293] = "lgs";
+      keyword[294] = "LSS";
+      keyword[295] = "lss";
+      keyword[296] = "SETAE";
+      keyword[297] = "setae";
+      keyword[298] = "SETA";
+      keyword[299] = "seta";
+      keyword[300] = "SETBE";
+      keyword[301] = "setbe";
+      keyword[302] = "SETB";
+      keyword[303] = "setb";
+      keyword[304] = "SETC";
+      keyword[305] = "setc";
+      keyword[306] = "SETE";
+      keyword[307] = "sete";
+      keyword[308] = "SETGE";
+      keyword[309] = "setge";
+      keyword[310] = "SETG";
+      keyword[311] = "setg";
+      keyword[312] = "SETLE";
+      keyword[313] = "setle";
+      keyword[314] = "SETL";
+      keyword[315] = "setl";
+      keyword[316] = "SETNAE";
+      keyword[317] = "setnae";
+      keyword[318] = "SETNA";
+      keyword[319] = "setna";
+      keyword[320] = "SETNBE";
+      keyword[321] = "setnbe";
+      keyword[322] = "SETNB";
+      keyword[323] = "setnb";
+      keyword[324] = "SETNC";
+      keyword[325] = "setnc";
+      keyword[326] = "SETNE";
+      keyword[327] = "setne";
+      keyword[328] = "SETNGE";
+      keyword[329] = "setnge";
+      keyword[330] = "SETNG";
+      keyword[331] = "setng";
+      keyword[332] = "SETNLE";
+      keyword[333] = "setnle";
+      keyword[334] = "SETNL";
+      keyword[335] = "setnl";
+      keyword[336] = "SETNO";
+      keyword[337] = "setno";
+      keyword[338] = "SETNP";
+      keyword[339] = "setnp";
+      keyword[340] = "SETNS";
+      keyword[341] = "setns";
+      keyword[342] = "SETNZ";
+      keyword[343] = "setnz";
+      keyword[344] = "SETO";
+      keyword[345] = "seto";
+      keyword[346] = "SETPE";
+      keyword[347] = "setpe";
+      keyword[348] = "SETPO";
+      keyword[349] = "setpo";
+      keyword[350] = "SETP";
+      keyword[351] = "setp";
+      keyword[352] = "SETS";
+      keyword[353] = "sets";
+      keyword[354] = "SETZ";
+      keyword[355] = "setz";
+      keyword[356] = "BSWAP";
+      keyword[357] = "bswap";
+      keyword[358] = "CMPXCHG";
+      keyword[359] = "cmpxchg";
+      keyword[360] = "INVD";
+      keyword[361] = "invd";
+      keyword[362] = "INVLPG";
+      keyword[363] = "invlpg";
+      keyword[364] = "WBINVD";
+      keyword[365] = "wbinvd";
+      keyword[366] = "XADD";
+      keyword[367] = "xadd";
+      keyword[368] = "CPUID";
+      keyword[369] = "cpuid";
+      keyword[370] = "CMPXCHG8B";
+      keyword[371] = "cmpxchg8b";
+      keyword[372] = "RDMSR";
+      keyword[373] = "rdmsr";
+      keyword[374] = "RDTSC";
+      keyword[375] = "rdtsc";
+      keyword[376] = "WRMSR";
+      keyword[377] = "wrmsr";
+      keyword[378] = "RSM";
+      keyword[379] = "rsm";
+      keyword[380] = "RDPMC";
+      keyword[381] = "rdpmc";
+      keyword[382] = "SYSCALL";
+      keyword[383] = "syscall";
+      keyword[384] = "SYSRET";
+      keyword[385] = "sysret";
+      keyword[386] = "CMOVAE";
+      keyword[387] = "cmovae";
+      keyword[388] = "CMOVA";
+      keyword[389] = "cmova";
+      keyword[390] = "CMOVBE";
+      keyword[391] = "cmovbe";
+      keyword[392] = "CMOVB";
+      keyword[393] = "cmovb";
+      keyword[394] = "CMOVCE";
+      keyword[395] = "cmovce";
+      keyword[396] = "CMOVC";
+      keyword[397] = "cmovc";
+      keyword[398] = "CMOVGE";
+      keyword[399] = "cmovge";
+      keyword[400] = "CMOVG";
+      keyword[401] = "cmovg";
+      keyword[402] = "CMOVLE";
+      keyword[403] = "cmovle";
+      keyword[404] = "CMOVL";
+      keyword[405] = "cmovl";
+      keyword[406] = "CMOVNAE";
+      keyword[407] = "cmovnae";
+      keyword[408] = "CMOVNA";
+      keyword[409] = "cmovna";
+      keyword[410] = "CMOVNBE";
+      keyword[411] = "cmovnbe";
+      keyword[412] = "CMOVNB";
+      keyword[413] = "cmovnb";
+      keyword[414] = "CMOVNC";
+      keyword[415] = "cmovnc";
+      keyword[416] = "CMOVNE";
+      keyword[417] = "cmovne";
+      keyword[418] = "CMOVNGE";
+      keyword[419] = "cmovnge";
+      keyword[420] = "CMOVNG";
+      keyword[421] = "cmovng";
+      keyword[422] = "CMOVNLE";
+      keyword[423] = "cmovnle";
+      keyword[424] = "CMOVNL";
+      keyword[425] = "cmovnl";
+      keyword[426] = "CMOVNO";
+      keyword[427] = "cmovno";
+      keyword[428] = "CMOVNP";
+      keyword[429] = "cmovnp";
+      keyword[430] = "CMOVNS";
+      keyword[431] = "cmovns";
+      keyword[432] = "CMOVNZ";
+      keyword[433] = "cmovnz";
+      keyword[434] = "CMOVO";
+      keyword[435] = "cmovo";
+      keyword[436] = "CMOVPE";
+      keyword[437] = "cmovpe";
+      keyword[438] = "CMOVPO";
+      keyword[439] = "cmovpe";
+      keyword[440] = "CMOVP";
+      keyword[441] = "cmovp";
+      keyword[442] = "CMOVS";
+      keyword[443] = "cmovs";
+      keyword[444] = "CMOVZ";
+      keyword[445] = "cmovz";
+      keyword[446] = "SYSENTER";
+      keyword[447] = "sysenter";
+      keyword[448] = "SYSEXIT";
+      keyword[449] = "sysexit";
+      keyword[450] = "UD2";
+      keyword[451] = "ud2";
+      keyword[452] = "MASKMOVQ";
+      keyword[453] = "maskmovq";
+      keyword[454] = "MOVNTPS";
+      keyword[455] = "movntps";
+      keyword[456] = "MOVNTQ";
+      keyword[457] = "movntq";
+      keyword[458] = "PREFETCH0";
+      keyword[459] = "prefetch0";
+      keyword[460] = "PREFETCH1";
+      keyword[461] = "prefetch1";
+      keyword[462] = "PREFETCH2";
+      keyword[463] = "prefetch2";
+      keyword[464] = "PREFETCHNTA";
+      keyword[465] = "prefetchnta";
+      keyword[466] = "SFENCE";
+      keyword[467] = "sfence";
+      keyword[468] = "CLFLUSH";
+      keyword[469] = "clflush";
+      keyword[470] = "LFENCE";
+      keyword[471] = "lfence";
+      keyword[472] = "MASKMOVDQ";
+      keyword[473] = "maskmovdq";
+      keyword[474] = "MFENCE";
+      keyword[475] = "mfence";
+      keyword[476] = "PAUSE";
+      keyword[477] = "pause";
+      keyword[478] = "LDDQU";
+      keyword[479] = "lddqu";
+      keyword[480] = "MONITOR";
+      keyword[481] = "monitor";
+      keyword[482] = "MWAIT";
+      keyword[483] = "mwait";
+      keyword[484] = "CDQE";
+      keyword[485] = "cdqe";
+      keyword[486] = "CQO";
+      keyword[487] = "cqo";
+      keyword[488] = "CMPSQ";
+      keyword[489] = "cmpsq";
+      keyword[490] = "CMPXCHG16B";
+      keyword[491] = "cmpxchg16b";
+      keyword[492] = "CMP";
+      keyword[493] = "cmp";
+      keyword[494] = "IRETQ";
+      keyword[495] = "iretq";
+      keyword[496] = "JRCXZ";
+      keyword[497] = "jrcxz";
+      keyword[498] = "LODSQ";
+      keyword[499] = "lodsq";
+      keyword[500] = "RDTSCP";
+      keyword[501] = "rdtscp";
+      keyword[502] = "SWAPGS";
+      keyword[503] = "swapgs";
+      keyword[504] = "stack";
+      keyword[505] = "data";
+      keyword[506] = "code";
+      keyword[507] = "text";
+      keyword[508] = "section";
+      keyword[509] = "start";
+      keyword[510] = "segment";
+      keyword[511] = "global";
+      keyword[512] = "bss";
+      total_keywords = 513;
+      break;
+      /////////////////////////////////////////////////
+      /////////////////////////////////////////////////
+      /////////////////////////////////////////////////
+    case(PYTHON_MODE):
+      //Python language keywords
+      keyword[0] = "print";
+      keyword[1] = "while";
+      keyword[2] = "for";
+      keyword[3] = "break";
+      keyword[4] = "continue";
+      keyword[5] = "if";
+      keyword[6] = "elif";
+      keyword[7] = "else";
+      keyword[8] = "is";
+      keyword[9] = "not";
+      keyword[10] = "and";
+      keyword[11] = "or";
+      keyword[12] = "import";
+      keyword[13] = "as";
+      keyword[14] = "from";
+      keyword[15] = "def";
+      keyword[16] = "return";
+      keyword[17] = "lambda";
+      keyword[18] = "global";
+      keyword[19] = "try";
+      keyword[20] = "except";
+      keyword[21] = "finally";
+      keyword[22] = "raise";
+      keyword[23] = "del";
+      keyword[24] = "pass";
+      keyword[25] = "assert";
+      keyword[26] = "class";
+      keyword[27] = "exec";
+      keyword[28] = "yield";
+      total_keywords = 29;
+      break;
+      /////////////////////////////////////////////////
+      /////////////////////////////////////////////////
+      /////////////////////////////////////////////////
     case(NO_MODE):
       break;
   }//end switch
