@@ -175,6 +175,8 @@ char dirStar[MAXDIRS];	//we need a byte-length declaration, so use char
 char fileStar[MAXFILES];//both of these indicate which dir/file is starred 
 			//(selected) in the view
 			//value 42 is '*' and value 32 is ' '
+char dirType[MAXDIRS];	//The type of dir: either hidden or regular dir
+char fileType[MAXFILES];//The type of file
 int activeWindow;	//int value indicating which window is active
 
 //values used in the activeWindow variable//
@@ -209,4 +211,17 @@ FILE *log_file;
 char *config_file_name;//string holding the name of the config file
 FILE *config_file;
 int GNU_DOS_LEVEL;
-#endif
+
+//Array to store different colors that will be given
+//to files of different types.. The array is indexed by
+//a character indicating the type of file/dir.. Currently,
+//the chars are:
+//'d' for directories
+//'x' for executable files
+//'r' for regular files
+//'l' for links
+//'a' for archives
+//'h' for hidden files
+//'p' for picture files
+char FILE_DIR_COLOR[26];
+#endif
\ No newline at end of file
