@@ -380,7 +380,8 @@ do_up:
        else 
        {
 	int j;
-	setScreenColors(GREEN, BGBLUE);
+	setScreenColors(FILE_DIR_COLOR[dirType[firstVisDir+selectedDir+1]-'a'], BGBLUE);
+	//setScreenColors(GREEN, BGBLUE);
 	fprintf(stdout, "\x1b[%d;%dH%s", selectedDir+5, 3, dirHighLight);
 	//fprintf(stdout, "\x1b[%d;%dH%c%s", selectedDir+5, 3, 
 	//	dirStar[firstVisDir+selectedDir+1], dirs[firstVisDir+selectedDir+1]);
@@ -430,7 +431,8 @@ do_up:
        } 
        else 
        {
-	setScreenColors(GREEN, BGBLUE);
+	setScreenColors(FILE_DIR_COLOR[fileType[firstVisFile+selectedFile+1]-'a'], BGBLUE);
+	//setScreenColors(GREEN, BGBLUE);
 	fprintf(stdout, "\x1b[%d;%dH%s", selectedFile+5, 
 		(SCREEN_W/2)+1, fileHighLight);
 	//fprintf(stdout, "\x1b[%d;%dH%c%s", selectedFile+5, (SCREEN_W/2)+1, 
@@ -491,7 +493,8 @@ do_down:
        else 
        {
 	 int j;
-	setScreenColors(GREEN, BGBLUE);
+	setScreenColors(FILE_DIR_COLOR[dirType[firstVisDir+selectedDir-1]-'a'], BGBLUE);
+	//setScreenColors(GREEN, BGBLUE);
 	fprintf(stdout, "\x1b[%d;%dH%s", selectedDir+3, 3, dirHighLight);
 	//fprintf(stdout, "\x1b[%d;%dH%c%s", selectedDir+3, 3, 
 	//	dirStar[firstVisDir+selectedDir-1], dirs[firstVisDir+selectedDir-1]);
@@ -546,7 +549,8 @@ do_down:
        else 
        {
 	 int j;
-	setScreenColors(GREEN, BGBLUE);
+	setScreenColors(FILE_DIR_COLOR[fileType[firstVisFile+selectedFile-1]-'a'], BGBLUE);
+	//setScreenColors(GREEN, BGBLUE);
 	fprintf(stdout, "\x1b[%d;%dH%s", selectedFile+3, 
 		(SCREEN_W/2)+1, fileHighLight);
 	//fprintf(stdout, "\x1b[%d;%dH%c%s", selectedFile+3, (SCREEN_W/2)+1, 
@@ -1091,6 +1095,10 @@ void scanDir(char *dir)
 	if(j == 1) dirStar[dcount-1] = '^';
 	else if(j == 2) dirStar[dcount-1] = '#';
 	else dirStar[dcount-1] = ' ';
+	//check if it is a hidden dir or not
+	if(dirs[dcount-1][0] == '.')
+	  dirType[dcount-1] = 'h';
+	else dirType[dcount-1] = 'd';
       } 
       else 
       {
@@ -1101,6 +1109,39 @@ void scanDir(char *dir)
 	if(j == 1) fileStar[fcount-1] = '^';
 	else if(j == 2) fileStar[fcount-1] = '#';
 	else fileStar[fcount-1] = ' ';
+	//check to see the file type
+	if(S_ISLNK(statbuf.st_mode))	//is it a link?
+	  fileType[fcount-1] = 'l';
+	else
+	{
+	  if(files[fcount-1][0] == '.')	//is it hidden?
+	    fileType[fcount-1] = 'h';
+	  else if(strstr(files[fcount-1], ".tar")
+	    || strstr(files[fcount-1], ".gz")
+	    || strstr(files[fcount-1], ".xz")
+	    || strstr(files[fcount-1], ".Z")
+	    || strstr(files[fcount-1], ".rar")
+	    || strstr(files[fcount-1], ".zip")
+	    || strstr(files[fcount-1], ".bz2")
+	    || strstr(files[fcount-1], ".7z")
+	    || strstr(files[fcount-1], ".lzma")
+	    || strstr(files[fcount-1], ".lha")
+	    || strstr(files[fcount-1], ".jar"))//is archive?
+	    fileType[fcount-1] = 'a';
+	  else if(strstr(files[fcount-1], ".bmp")
+	    || strstr(files[fcount-1], ".png")
+	    || strstr(files[fcount-1], ".jpg")
+	    || strstr(files[fcount-1], ".jpeg")
+	    || strstr(files[fcount-1], ".gif")
+	    || strstr(files[fcount-1], ".tiff"))//is picture?
+	    fileType[fcount-1] = 'p';
+	  else if((statbuf.st_mode & S_IXUSR)
+	    || (statbuf.st_mode & S_IXGRP)
+	    || (statbuf.st_mode & S_IXOTH)) //is executable?
+	    fileType[fcount-1] = 'x';
+	  else	//just a regular file
+	    fileType[fcount-1] = 'r';
+	}//end file type check
       }
     }
   } 
@@ -1158,7 +1199,7 @@ void refreshDirView()
    refreshDirView();//this will make an infinite loop.. solution??
    return;
  }
- setScreenColors(GREEN, BGBLUE);
+ //setScreenColors(GREEN, BGBLUE);
  for(i = 0; i < numVisDirs; i++) 
  {
    if(dirs[firstVisDir+i] == NULL) break; 
@@ -1177,10 +1218,11 @@ void refreshDirView()
 	fprintf(stdout, "\x1b[%d;%dH%c%s", i+4, 3, 
 		dirStar[firstVisDir+i], dirs[firstVisDir+i]);
       }//end if
-      setScreenColors(GREEN, BGBLUE);
+      //setScreenColors(GREEN, BGBLUE);
     } 
     else 
     {
+      setScreenColors(FILE_DIR_COLOR[dirType[firstVisDir+i]-'a'], BGBLUE);
       if(strlen(dirs[firstVisDir+i]) >= MAX_DIR_NAME_LEN) 
       {
 	fprintf(stdout, "\x1b[%d;%dH%c", i+4, 3, dirStar[firstVisDir+i]);
@@ -1223,7 +1265,7 @@ void refreshFileView()
    files[1] = NULL;
    totalFiles = 1;
  }
- setScreenColors(GREEN, BGBLUE);
+ //setScreenColors(GREEN, BGBLUE);
  for(i = 0; i < numVisFiles; i++) 
  {
     if(files[firstVisFile+i] == NULL) break; 
@@ -1243,10 +1285,11 @@ void refreshFileView()
 	fprintf(stdout, "\x1b[%d;%dH%c%s", i+4, (SCREEN_W/2)+1, 
 		      fileStar[firstVisFile+i], files[firstVisFile+i]);
       }//end if
-      setScreenColors(GREEN, BGBLUE);
+      //setScreenColors(GREEN, BGBLUE);
     } 
     else 
     {
+	setScreenColors(FILE_DIR_COLOR[fileType[firstVisFile+i]-'a'], BGBLUE);
 	if(strlen(files[firstVisFile+i]) >= MAX_FILE_NAME_LEN) 
 	{
 	  fprintf(stdout, "\x1b[%d;%dH%c", i+4, (SCREEN_W/2)+1, 
@@ -1346,7 +1389,16 @@ void drawMenuBar(int x, int y, int w)
  * **************************************/
 void init() 
 {
- getScreenSize();
+  getScreenSize();
+  //define colors that will be used to colorize the view
+  FILE_DIR_COLOR['d'-'a'] = WHITE;	//color for directories
+  FILE_DIR_COLOR['x'-'a'] = GREEN;	//color for exec files
+  FILE_DIR_COLOR['r'-'a'] = WHITE;	//color for regular files
+  FILE_DIR_COLOR['l'-'a'] = CYAN;	//color for links
+  FILE_DIR_COLOR['a'-'a'] = RED;	//color for archives
+  FILE_DIR_COLOR['h'-'a'] = BROWN;	//color for hidden files
+  FILE_DIR_COLOR['p'-'a'] = MAGENTA;	//color for picture files
+
   //1. Main Menu//
   menu[0] = "&File";
   menu[1] = "&Edit";
@@ -1400,10 +1452,12 @@ void init()
  {
    dirStar[i] = ' ';
    dirs[i] = (char *) malloc(MAX_DIR_NAME_LEN);
+   dirType[i] = 'd';
  }
  for(i = 0; i < MAXFILES; i++) 
  {
    fileStar[i] = ' ';
+   fileType[i] = 'r';
    files[i] = (char *) malloc(MAX_FILE_NAME_LEN);
  }
   
