@@ -387,7 +387,7 @@ void showHelpMenu(int visible)
   if(visible == YES) 
   {	//show the file menu
     //activeWindow = HELP_MENU;
-    drawBox(3, 14, 7, 31, NULL, YES);
+    drawBox(3, 14, 8, 31, NULL, YES);
     setScreenColors(BLUE, BGWHITE);
     fprintf(stdout, "\e[4;15H%s", helpMenu[0]);
     setScreenColors(WHITE, BGBLUE);
@@ -466,14 +466,18 @@ void showHelpMenu(int visible)
 	    fprintf(log_file, "Opening README..\n");
 	    showReadMe();
 	  } 
-	  else if(hSelect == 2) 
+	  else if(hSelect == 1) 
+	  {			//show KEYBINDINGS file
+	    showKeybindings();
+	  } 
+	  else if(hSelect == 3) 
 	  {		//show About msgbox
 	    fprintf(log_file, "Opening About dialog box..\n");
 	    char *x = " Prime for GNU/Linux. \n Developed by \
 Mohammed Isam, \n 2013, 2014. ";
 	    msgBox(x, OK, INFO);
 	  } 
-	  else if(hSelect == 1) 
+	  else if(hSelect == 2) 
 	  {	//show Quick reference
 	    fprintf(log_file, "Opening Quick reference..\n");
 	    drawBox(3, 5, 18, SCREEN_W-5, "Quick Reference", YES);
@@ -513,6 +517,145 @@ Mohammed Isam, \n 2013, 2014. ";
   fprintf(log_file, "Returning to main program from Help Menu\n");
 }
 
+
+////////////////////////////////////////////////////////
+//shows a window with KEYBINDINGS file as its contents//
+////////////////////////////////////////////////////////
+void showKeybindings() 
+{
+  int x = 2;
+  int y = 2;
+  int w = SCREEN_W-1;
+  int h = SCREEN_H-1;
+  FILE *KEYBINDINGS;
+  char buf[4096*4];	//buffer to hold data
+  int buf_len = 0;
+  
+  if(!(KEYBINDINGS = fopen("/usr/share/doc/gnudos/prime/keybindings", "r"))) 
+  {
+   if(!(KEYBINDINGS = fopen("/usr/local/share/doc/gnudos/prime/keybindings", "r"))) 
+   {
+    msgBox("Failed to open KEYBINDINGS file!.", OK, ERROR);
+    fprintf(log_file, "Failed to open /usr/share/doc/gnudos/prime/keybindings file..\n");
+    scanDir(cwd);
+    return;
+   }
+  }
+  
+  if(!(buf_len = fread(buf, sizeof(char), sizeof(buf), KEYBINDINGS))) 
+  {
+    msgBox("Failed to read the KEYBINDINGS file!.", OK, ERROR);
+    fprintf(log_file, "Failed to open /usr/share/doc/gnudos/prime/keybindings file..\n");
+    scanDir(cwd);
+    return;
+  }
+  
+  drawBox(x, y, h, w, " KEYBINDINGS ", YES);
+  
+  y++; x++;
+  int i = 0, j = x;
+  int l = y;
+  int lineStart[60];
+  int firstVisLine = 0;
+  int cnt = 0;
+  //char *ch = (char *)malloc(5);
+  int ch;
+  char moreLines = 1;	//used as boolean to indicate if still more lines
+  lineStart[0] = 0;
+  
+  fprintf(stdout, "\e[%d;%dH", j, l);
+  //for(i = 0; i < buf_len; i++) {
+  while(j < (h-x+2)) 
+  {
+    if(buf[i] == EOL) 
+    { 
+      lineStart[++cnt] = i+1;
+      l=y;
+      fprintf(stdout, "\e[%d;%dH", ++j, l); 
+    } 
+    else 
+    { 
+      if(l > (w-y+2)) 
+      {
+	lineStart[++cnt] = i;
+	l=y;
+	fprintf(stdout, "\e[%d;%dH", ++j, l);
+      } putchar(buf[i]); l++;
+    }
+    if(++i >= buf_len) break;
+  }
+  
+  fflush(stdout);
+  //if the output chars are less than the buffer length,
+  //it means there are more lines to the output.
+  if(i <= buf_len) 
+  {
+    goto readMore;
+  } 
+  else 
+  {
+    do {;} while(!getKey());
+    goto end;
+    return;
+  }
+  
+readMore:
+  while(1) {
+    ch = getKey();
+    switch(ch) {
+      case(ENTER_KEY):
+      case(SPACE_KEY):
+      case(ESC_KEY):
+	goto end;
+	break;
+      case(UP_KEY):
+	if(firstVisLine == 0) break;	//can't go up--first line already
+	firstVisLine--;
+	break;
+      case(DOWN_KEY):
+	if(!moreLines) break;	//reached last line
+	firstVisLine++;
+	break;
+    }	//end of switch
+    //redraw the box with its contents
+    drawBox(x-1, y-1, h, w, " KEYBINDINGS ", YES);
+    j = x; l = y; cnt = firstVisLine; i = lineStart[firstVisLine];
+    
+    fprintf(stdout, "\e[%d;%dH", j, l);
+    while(j < (h-x+2)) 
+    {
+     if(buf[i] == EOL) 
+     { 
+      lineStart[++cnt] = i+1;
+      l=y;
+      fprintf(stdout, "\e[%d;%dH", ++j, l); 
+     } 
+     else 
+     { 
+      if(l > (w-y+2)) 
+      {
+	lineStart[++cnt] = i;
+	l=y;
+	fprintf(stdout, "\e[%d;%dH", ++j, l);
+      } putchar(buf[i]); l++;
+     }
+     if(++i >= buf_len) break;
+    }	//end of inner while
+    if(i <= buf_len) { moreLines = 1; }
+    else { moreLines = 0; }
+    fflush(stdout);
+
+  }	//end of outer while
+end:
+  fclose(KEYBINDINGS);
+  //free(buf);
+  drawMenuBar(2, 2, SCREEN_W-2);	//draw main menu bar
+  scanDir(cwd);
+  //fflush(stdout);
+  return;
+}
+
+
 /******************************************
  * this function shows a window with 
  * README file as its contents.
